package kaysaar.aotd_question_of_loyalty.data.scripts.trackers;

import com.fs.starfarer.api.impl.campaign.intel.events.EventFactor;
import kaysaar.aotd_question_of_loyalty.data.intel.eventfactors.onetime.ExplorationCompletionFactor;
import kaysaar.aotd_question_of_loyalty.data.intel.AoTDCommIntelPlugin;
import kaysaar.aotd_question_of_loyalty.data.plugins.ReflectionUtilis;
import com.fs.starfarer.api.impl.campaign.intel.BaseMissionIntel;
import kaysaar.aotd_question_of_loyalty.data.misc.QoLMisc;
import java.util.Iterator;
import com.fs.starfarer.api.campaign.comm.IntelInfoPlugin;
import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.impl.campaign.intel.SurveyPlanetMissionIntel;
import com.fs.starfarer.api.impl.campaign.intel.AnalyzeEntityMissionIntel;
import java.util.ArrayList;
import com.fs.starfarer.api.EveryFrameScript;

public class ExplorationTracker implements EveryFrameScript
{
    protected ArrayList<AnalyzeEntityMissionIntel> entityMissionIntels;
    protected ArrayList<SurveyPlanetMissionIntel> surveyPlanetMissionIntels;
    
    public ExplorationTracker() {
        this.entityMissionIntels = new ArrayList<AnalyzeEntityMissionIntel>();
        this.surveyPlanetMissionIntels = new ArrayList<SurveyPlanetMissionIntel>();
    }
    
    public boolean isDone() {
        return false;
    }
    
    public boolean runWhilePaused() {
        return false;
    }
    
    public void advance(final float amount) {
        this.handleAnalyzingMissions();
        this.handleSurveyMissions();
    }
    
    public ArrayList<AnalyzeEntityMissionIntel> getEntityMissions() {
        final ArrayList<AnalyzeEntityMissionIntel> bounties = new ArrayList<AnalyzeEntityMissionIntel>();
        for (final IntelInfoPlugin intelInfoPlugin : Global.getSector().getIntelManager().getIntel((Class)AnalyzeEntityMissionIntel.class)) {
            if (intelInfoPlugin instanceof final AnalyzeEntityMissionIntel analyzeEntityMissionIntel) {
                bounties.add(analyzeEntityMissionIntel);
            }
        }
        return bounties;
    }
    
    public boolean isBaseMissionPresent(final AnalyzeEntityMissionIntel bounty) {
        for (final AnalyzeEntityMissionIntel baseCustomBounty : this.entityMissionIntels) {
            if (bounty.equals(baseCustomBounty)) {
                return true;
            }
        }
        return false;
    }
    
    private void handleAnalyzingMissions() {
        for (final AnalyzeEntityMissionIntel bounty : this.getEntityMissions()) {
            if (bounty.getMissionState() != null && QoLMisc.isCommissionedBy(bounty.getFactionForUIColors().getId()) && !this.isBaseMissionPresent(bounty)) {
                this.entityMissionIntels.add(bounty);
                if (!bounty.getMissionState().equals((Object)BaseMissionIntel.MissionState.COMPLETED)) {
                    continue;
                }
                try {
                    final int reward = (int)ReflectionUtilis.getPrivateVariable("reward", (Object)bounty);
                    final int points = reward / 2000;
                    AoTDCommIntelPlugin.get().addFactor((EventFactor)new ExplorationCompletionFactor(points));
                }
                catch (final Exception ex) {}
            }
        }
        final Iterator<AnalyzeEntityMissionIntel> iterator = this.entityMissionIntels.iterator();
        while (iterator.hasNext()) {
            final AnalyzeEntityMissionIntel baseCustomBounty = iterator.next();
            if (baseCustomBounty.isEnded()) {
                iterator.remove();
            }
        }
    }
    
    public ArrayList<SurveyPlanetMissionIntel> getSurveyMissions() {
        final ArrayList<SurveyPlanetMissionIntel> bounties = new ArrayList<SurveyPlanetMissionIntel>();
        for (final IntelInfoPlugin intelInfoPlugin : Global.getSector().getIntelManager().getIntel((Class)SurveyPlanetMissionIntel.class)) {
            if (intelInfoPlugin instanceof final SurveyPlanetMissionIntel surveyPlanetMissionIntel) {
                bounties.add(surveyPlanetMissionIntel);
            }
        }
        return bounties;
    }
    
    public boolean isSurveyMissionPresent(final SurveyPlanetMissionIntel bounty) {
        for (final SurveyPlanetMissionIntel baseCustomBounty : this.surveyPlanetMissionIntels) {
            if (bounty.equals(baseCustomBounty)) {
                return true;
            }
        }
        return false;
    }
    
    private void handleSurveyMissions() {
        for (final SurveyPlanetMissionIntel bounty : this.getSurveyMissions()) {
            if (bounty.getMissionState() != null && bounty.getMissionState() != BaseMissionIntel.MissionState.ACCEPTED && QoLMisc.isCommissionedBy(bounty.getFactionForUIColors().getId()) && !this.isSurveyMissionPresent(bounty)) {
                this.surveyPlanetMissionIntels.add(bounty);
                if (!bounty.getMissionState().equals((Object)BaseMissionIntel.MissionState.COMPLETED)) {
                    continue;
                }
                try {
                    final int reward = (int)ReflectionUtilis.getPrivateVariable("reward", (Object)bounty);
                    final int points = reward / 2000;
                    AoTDCommIntelPlugin.get().addFactor((EventFactor)new ExplorationCompletionFactor(points));
                }
                catch (final Exception ex) {}
            }
        }
        final Iterator<SurveyPlanetMissionIntel> iterator = this.surveyPlanetMissionIntels.iterator();
        while (iterator.hasNext()) {
            final SurveyPlanetMissionIntel baseCustomBounty = iterator.next();
            if (baseCustomBounty.isEnded()) {
                iterator.remove();
            }
        }
    }
}
